@@ -10,7 +10,7 @@ from tensorflow.python.keras.layers import (
     AveragePooling2D,
     AveragePooling3D,
 )
-from onnx2tf.utils.colors import Color
+from onnx2tf.utils.logging import *
 from onnx2tf.utils.common_functions import (
     get_constant_or_variable,
     print_node_info,
@@ -92,8 +92,6 @@ def make_node(
         if isinstance(graph_node_input, gs.Variable) else graph_node_input
     input_tensor_shape = input_tensor.shape
 
-    non_verbose = bool(kwargs['non_verbose'])
-
     # Pre-process transpose
     input_tensor = pre_process_transpose(
         value_before_transpose=input_tensor,
@@ -165,7 +163,8 @@ def make_node(
     tf_pads = calc_tf_pooling_pads(
         input_shape=input_tensor_shape,
         kernel=kernel_shape,
-        strides=strides
+        strides=strides,
+        input_tensor=input_tensor
     )
 
     func = math.ceil if ceil_mode else math.floor
@@ -212,7 +211,7 @@ def make_node(
         tf_pads = [0] * spatial_size * 2
 
     else:
-        error_msg = f'{Color.RED}ERROR:{Color.RESET} ' + \
+        error_msg = Color.RED(f'ERROR:') + ' ' + \
                     f'Wrong auto_pad parameter in AveragePool: {auto_pad}.'
         raise ValueError(error_msg)
 
@@ -248,12 +247,10 @@ def make_node(
     # 2. when extra padding layer is not added and count_include_pad is True
     # 3. when last stride has extra padding due to ceil_mode and count_include_pad is True
     if is_explicit_padding and tf_pads != [0] * spatial_size * 2:
-        if not non_verbose:
-            warning_msg = \
-                f'{Color.YELLOW}WARNING:{Color.RESET} ' \
-                f'Tensorflow incompatible padding detected. ' \
-                f'Extra pad layer is inserted automatically. '
-            print(warning_msg)
+        warn(
+            f'Tensorflow incompatible padding detected. ' \
+            f'Extra pad layer is inserted automatically. '
+        )
 
         if auto_pad == 'SAME_LOWER':
             # switch the order of pads
@@ -271,11 +268,14 @@ def make_node(
             [list(i) for i in zip(tf_pads[:len(tf_pads) // 2], tf_pads[len(tf_pads) // 2:])] + \
             [[0, 0]]
 
-        padded_tensor = tf.pad(
-            tensor=input_tensor,
-            paddings=tf_pads,
-            mode='CONSTANT',
-        )
+        if spatial_size == 1 and kernel_shape[0] > input_tensor_shape[1]:
+            padded_tensor = input_tensor
+        else:
+            padded_tensor = tf.pad(
+                tensor=input_tensor,
+                paddings=tf_pads,
+                mode='CONSTANT',
+            )
 
     else:
         padded_tensor = input_tensor
@@ -309,11 +309,18 @@ def make_node(
     # Generation of TF OP
     tf_op_type = None
     if len(kernel_shape) == 1:
-        pooled_tensor = AveragePooling1D(
-            pool_size=kernel_shape,
-            strides=strides,
-            padding=tf_pad_mode.upper(),
-        )(padded_tensor)
+        if kernel_shape[0] > padded_tensor.shape[1]:
+            pooled_tensor = AveragePooling1D(
+                pool_size=[padded_tensor.shape[1]],
+                strides=[padded_tensor.shape[1]],
+                padding=tf_pad_mode.upper(),
+            )(padded_tensor)
+        else:
+            pooled_tensor = AveragePooling1D(
+                pool_size=kernel_shape,
+                strides=strides,
+                padding=tf_pad_mode.upper(),
+            )(padded_tensor)
         tf_op_type = AveragePooling1D
 
     elif len(kernel_shape) == 2:
@@ -334,7 +341,7 @@ def make_node(
 
     else:
         error_msg = f'' +\
-            f'{Color.RED}ERROR:{Color.RESET} ' +\
+            Color.RED(f'ERROR:') + ' ' +\
             f'AveragePool supports only 1D, 2D, and 3D. ' +\
             f'opname: {graph_node.name} Type: AveragePool{len(kernel_shape)}D'
         print(error_msg)
@@ -343,14 +350,12 @@ def make_node(
     # tensorflow average pooling needs extra process to get same output with onnx
     # https://github.com/PINTO0309/onnx2tf/issues/124
     if average_multiplier is not None:
-        if not non_verbose:
-            warning_msg = \
-                f'{Color.YELLOW}WARNING:{Color.RESET} ' \
-                f'Tensorflow incompatible action detected. ' \
-                f'Some additional layers are inserted to reproduce same output. ' \
-                f'Please refer to the following link for more information: ' \
-                f'https://github.com/PINTO0309/onnx2tf/issues/124'
-            print(warning_msg)
+        warn(
+            f'Tensorflow incompatible action detected. ' \
+            f'Some additional layers are inserted to reproduce same output. ' \
+            f'Please refer to the following link for more information: ' \
+            f'https://github.com/PINTO0309/onnx2tf/issues/124'
+        )
 
         average_multiplier = summarize_multiplier(average_multiplier)
 
