@@ -52,11 +52,14 @@ def make_node(
 
     graph_node_input_1 = get_constant_or_variable(
         graph_node.inputs[0],
-        before_op_output_shape_trans,
+        before_op_output_shape_trans \
+            if graph_node.inputs[0].shape is not None and len(graph_node.inputs[0].shape) != 1 else False,
     )
     graph_node_input_2 = get_constant_or_variable(
         graph_node.inputs[1],
-        before_op_output_shape_trans,
+        before_op_output_shape_trans \
+            if graph_node.inputs[1].shape is not None and len(graph_node.inputs[1].shape) != 1 else False,
+
     )
     graph_node_output: gs.Variable = graph_node.outputs[0]
     graph_node_output_shape = graph_node_output.shape
@@ -145,19 +148,74 @@ def make_node(
             **kwargs,
         )
 
-    input_tensor_1, input_tensor_2 = \
-        pre_explicit_broadcast(
-            input_tensor_1=input_tensor_1,
-            input_tensor_2=input_tensor_2,
-        )
+    try:
+        is_scalar_1 = False
+        is_scalar_2 = False
+        is_scalar_1_rank = tf.rank(input_tensor_1) == 0
+        if hasattr(is_scalar_1_rank, 'numpy'):
+            is_scalar_1 = is_scalar_1_rank.numpy()
+        is_scalar_2_rank = tf.rank(input_tensor_2) == 0
+        if hasattr(is_scalar_2_rank, 'numpy'):
+            is_scalar_2 = is_scalar_2_rank.numpy()
 
-    input_tensor_1, input_tensor_2 = \
-        explicit_broadcast(
-            const_or_var_1=input_tensor_1,
-            const_or_var_2=input_tensor_2,
-            graph_node=graph_node,
-            tf_layers_dict= tf_layers_dict,
-        )
+        if (is_scalar_1 or is_scalar_2) and graph_node.i().op == 'Gemm':
+            pass
+        elif (is_scalar_1 or is_scalar_2) and graph_node.i().op != 'Gemm':
+            first_tensor = None
+            second_tensor = None
+            if is_scalar_1:
+                first_tensor = input_tensor_2
+                second_tensor = input_tensor_1
+            elif is_scalar_2:
+                first_tensor = input_tensor_1
+                second_tensor = input_tensor_2
+            tmp_result = tf.math.mod(first_tensor, second_tensor)
+            tmp_result_shape = tmp_result.shape
+            if first_tensor.shape == tmp_result_shape:
+                pass
+            else:
+                input_tensor_1, input_tensor_2 = \
+                    pre_explicit_broadcast(
+                        input_tensor_1=input_tensor_1,
+                        input_tensor_2=input_tensor_2,
+                    )
+
+                input_tensor_1, input_tensor_2 = \
+                    explicit_broadcast(
+                        const_or_var_1=input_tensor_1,
+                        const_or_var_2=input_tensor_2,
+                        graph_node=graph_node,
+                        tf_layers_dict= tf_layers_dict,
+                    )
+
+        else:
+            input_tensor_1, input_tensor_2 = \
+                pre_explicit_broadcast(
+                    input_tensor_1=input_tensor_1,
+                    input_tensor_2=input_tensor_2,
+                )
+
+            input_tensor_1, input_tensor_2 = \
+                explicit_broadcast(
+                    const_or_var_1=input_tensor_1,
+                    const_or_var_2=input_tensor_2,
+                    graph_node=graph_node,
+                    tf_layers_dict= tf_layers_dict,
+                )
+    except Exception as ex:
+        input_tensor_1, input_tensor_2 = \
+            pre_explicit_broadcast(
+                input_tensor_1=input_tensor_1,
+                input_tensor_2=input_tensor_2,
+            )
+
+        input_tensor_1, input_tensor_2 = \
+            explicit_broadcast(
+                const_or_var_1=input_tensor_1,
+                const_or_var_2=input_tensor_2,
+                graph_node=graph_node,
+                tf_layers_dict= tf_layers_dict,
+            )
 
     # Deterring shape corruption due to broadcast
     input_tensor_1, input_tensor_2 = \
