@@ -4,6 +4,7 @@ random.seed(0)
 import numpy as np
 np.random.seed(0)
 import tensorflow as tf
+import tf_keras
 import onnx_graphsurgeon as gs
 from onnx2tf.utils.common_functions import (
     replace_parameter,
@@ -16,14 +17,14 @@ from onnx2tf.utils.common_functions import (
     post_process_transpose,
     transpose_with_flexing_deterrence,
 )
-from onnx2tf.utils.colors import Color
+from onnx2tf.utils.logging import *
 
 from tensorflow.python.framework import ops
 from tensorflow.python.ops import gen_image_ops
 from tensorflow.python.util import dispatch
 
 
-class NMSLayer(tf.keras.layers.Layer):
+class NMSLayer(tf_keras.layers.Layer):
     def __init__(self):
         super(NMSLayer, self).__init__()
 
@@ -277,8 +278,7 @@ def make_node(
     num_batches = boxes.shape[0]
 
     if num_batches is None:
-        print(
-            f'{Color.RED}ERROR:{Color.RESET} ' +
+        error(
             f'It is not possible to specify a dynamic shape ' +
             f'for the batch size of the input tensor in NonMaxSuppression. ' +
             f'Use the --batch_size option to change the batch size to a fixed size. \n' +
